# xypyutil
Overview
- Inspired by [kkpyutil](https://github.com/kakyoism/kkpyutil) , combined with my own needs, I decided to fork a version and develop it incrementally on my own

Premises
- Provide one-liner APIs to simplify generic cross-platform sys-admin tasks
- Act as a thin wrapper over Python stdlibs, system builtin programs, and well-known 3rd-party standalone programs
- Avoid dependency on third-party packages

## INSTALL

```shell
pip3 install xypyutil
```
